﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using Microsoft.Phone.BackgroundTransfer;
using System.IO.IsolatedStorage;

namespace Phone_后台传输
{
    public partial class MainPage : PhoneApplicationPage
    {
        // 构造函数
        public MainPage()
        {
            InitializeComponent();
        }

        protected override void OnNavigatedTo(System.Windows.Navigation.NavigationEventArgs e)
        {

            initTransferRequest();
            base.OnNavigatedTo(e);
        }

        private void initTransferRequest()
        {
            //获取第一个后台传输任务
            var transferRequest = BackgroundTransferService.Requests.FirstOrDefault();
            if (transferRequest == null)
            {
                textblock1.Text = "无后台传输任务";
                button1.IsEnabled = true;
                return;
            }

            //当传输状态改变时：
            transferRequest.TransferStatusChanged += new EventHandler<BackgroundTransferEventArgs>(transfer_TransferStatusChanged);
            //当传输进度改变时：
            transferRequest.TransferProgressChanged += new EventHandler<BackgroundTransferEventArgs>(transfer_TransferProgressChanged);
            updatesStatus(transferRequest);
            button1.IsEnabled = false;
        }

        void transfer_TransferStatusChanged(object sender, BackgroundTransferEventArgs e)
        {
            updatesStatus(e.Request);
        }

        void transfer_TransferProgressChanged(object sender, BackgroundTransferEventArgs e)
        {
            updatesStatus(e.Request);
        }


        void updatesStatus(BackgroundTransferRequest transferRequest)
        {
            textblock1.Text = "传输状态：" + transferRequest.TransferStatus.ToString()
                + " 已下载字节：" + transferRequest.BytesReceived
                + "总字节：" + transferRequest.TotalBytesToReceive;
        }

        private void Button_Click_1(object sender, RoutedEventArgs e)
        {
            string fileurlstring = "http://images.cnblogs.com/cnblogs_com/lipan/319399/o_Large.png";
            Uri uri = new Uri(Uri.EscapeUriString(fileurlstring), UriKind.RelativeOrAbsolute);
            BackgroundTransferRequest transferRequest = new BackgroundTransferRequest(uri);
            transferRequest.Method = "GET";

            using (IsolatedStorageFile isoStore = IsolatedStorageFile.GetUserStoreForApplication())
            {
                if (!isoStore.DirectoryExists("/shared/transfers"))
                {
                    isoStore.CreateDirectory("/shared/transfers");
                }
            }

            //文件下载后存放位置（为本地文件夹相对位置）
            transferRequest.DownloadLocation = new Uri("shared/transfers/1.png", UriKind.RelativeOrAbsolute);
            //外接电源、WiFi的可用性对传输的影响
            transferRequest.TransferPreferences = TransferPreferences.AllowCellularAndBattery;

            try
            {
                //添加到后台传输队列中
                BackgroundTransferService.Add(transferRequest);
            }
            catch (Exception ex)
            {
                MessageBox.Show("无法添加后台传输请求。" + ex.Message);
            }
            initTransferRequest();
        }

        //清除传输队列已完成的任务
        private void Button_Click_2(object sender, RoutedEventArgs e)
        {
            foreach (var transferRequest in BackgroundTransferService.Requests)
            {
                if (transferRequest.TransferStatus == TransferStatus.Completed)
                {
                    try
                    {
                        BackgroundTransferService.Remove(transferRequest);
                    }
                    catch
                    {
                    }
                }
            }
            initTransferRequest();
        }

    }
}